<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * DepositosUbicas Model
 *
 * @property \App\Model\Table\DepositosTable|\Cake\ORM\Association\BelongsTo $Depositos
 * @property \App\Model\Table\UbicasTable|\Cake\ORM\Association\BelongsTo $Ubicas
 *
 * @method \App\Model\Entity\DepositosUbica get($primaryKey, $options = [])
 * @method \App\Model\Entity\DepositosUbica newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\DepositosUbica[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\DepositosUbica|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\DepositosUbica|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\DepositosUbica patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\DepositosUbica[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\DepositosUbica findOrCreate($search, callable $callback = null, $options = [])
 */
class DepositosUbicasTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('depositos_ubicas');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Depositos', [
            'foreignKey' => 'deposito_id'
        ]);
        $this->belongsTo('Ubicas', [
            'foreignKey' => 'ubica_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
         ->requirePresence('deposito_id', 'create');

         $validator
         ->requirePresence('ubica_id', 'create');

        $validator
            ->scalar('chasis')
            ->maxLength('chasis', 250)
            ->allowEmpty('chasis');

        $validator
            ->integer('estado')
            ->allowEmpty('estado');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['deposito_id'], 'Depositos'));
        $rules->add($rules->existsIn(['ubica_id'], 'Ubicas'));

        return $rules;
    }
}
