<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * InventarioUsados Model
 *
 * @method \App\Model\Entity\InventarioUsado get($primaryKey, $options = [])
 * @method \App\Model\Entity\InventarioUsado newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\InventarioUsado[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\InventarioUsado|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\InventarioUsado|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\InventarioUsado patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\InventarioUsado[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\InventarioUsado findOrCreate($search, callable $callback = null, $options = [])
 */
class InventarioUsadosTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('inventario_usados');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 250)
            ->requirePresence('fecha', 'create')
            ->notEmpty('fecha');

        $validator
            ->integer('usuario')
            ->allowEmpty('usuario');

        $validator
            ->scalar('modelo')
            ->maxLength('modelo', 250)
            ->requirePresence('modelo', 'create')
            ->notEmpty('modelo');

        $validator
            ->scalar('marca')
            ->maxLength('marca', 250)
            ->requirePresence('marca', 'create')
            ->notEmpty('marca');

        $validator
            ->scalar('color')
            ->maxLength('color', 250)
            ->requirePresence('color', 'create')
            ->notEmpty('color');

        $validator
            ->scalar('chasis')
            ->maxLength('chasis', 250)
            ->requirePresence('chasis', 'create')
            ->notEmpty('chasis')
            ->add('chasis', 'unique', ['rule' => 'validateUnique', 'provider' => 'table']);

        $validator
            ->integer('cuentaaceite')
            ->allowEmpty('cuentaaceite');

        $validator
            ->integer('motorfunciona')
            ->allowEmpty('motorfunciona');

        $validator
            ->integer('cajafunciona')
            ->allowEmpty('cajafunciona');

        $validator
            ->integer('chequin')
            ->allowEmpty('chequin');

        $validator
            ->integer('radiotv')
            ->allowEmpty('radiotv');

        $validator
            ->integer('insigniatrasera')
            ->allowEmpty('insigniatrasera');

        $validator
            ->integer('insigniadetalantera')
            ->allowEmpty('insigniadetalantera');

        $validator
            ->integer('cabeceras')
            ->allowEmpty('cabeceras');

        $validator
            ->integer('bocina')
            ->allowEmpty('bocina');

        $validator
            ->integer('aire')
            ->allowEmpty('aire');

        $validator
            ->integer('bloqueopuerta')
            ->allowEmpty('bloqueopuerta');

        $validator
            ->integer('tapizados')
            ->allowEmpty('tapizados');

        $validator
            ->integer('luces')
            ->allowEmpty('luces');

        $validator
            ->integer('espejos')
            ->allowEmpty('espejos');

        $validator
            ->integer('herramientas')
            ->allowEmpty('herramientas');

        $validator
            ->scalar('observacion')
            ->maxLength('observacion', 1000)
            ->allowEmpty('observacion');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->isUnique(['chasis']));

        return $rules;
    }
}
