<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * Publicacions Model
 *
 * @property \App\Model\Table\EmpleadosTable|\Cake\ORM\Association\BelongsTo $Empleados
 *
 * @method \App\Model\Entity\Publicacion get($primaryKey, $options = [])
 * @method \App\Model\Entity\Publicacion newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\Publicacion[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\Publicacion|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Publicacion|bool saveOrFail(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\Publicacion patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\Publicacion[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\Publicacion findOrCreate($search, callable $callback = null, $options = [])
 */
class PublicacionsTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('publicacions');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->belongsTo('Empleados', [
            'foreignKey' => 'empleado_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->integer('id')
            ->allowEmpty('id', 'create');

        $validator
            ->numeric('cantidad')
            ->allowEmpty('cantidad');

        $validator
            ->scalar('fecha')
            ->maxLength('fecha', 50)
            ->allowEmpty('fecha');

        $validator
            ->scalar('fechagenerado')
            ->maxLength('fechagenerado', 50)
            ->allowEmpty('fechagenerado');

        $validator
            ->integer('usuariogenerado')
            ->allowEmpty('usuariogenerado');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['empleado_id'], 'Empleados'));

        return $rules;
    }
}
